@@ -8,7 +8,11 @@ huge-sort.pl --keep test-B1.bigrams
 sort test-B1.bigrams-sorted > t0
 sort test-B1.reqd > t1
 
+if (-e test-B1.bigrams-sorted) then
 diff -w t0 t1 > var
+else
+    echo "Test Error";
+endif
 
 if(-z var) then
 	echo "Test Ok";
